@@ -1,8 +1,8 @@
 /*
 **  AccountEditorWindowController.m
 **
-**  Copyright (c) 2003-2007
-**                2014
+**  Copyright (C) 2003-2007 Ludovic Marcotte
+**  Copyright (C) 2014-2017 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -18,8 +18,7 @@
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
-**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+**  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #import "AccountEditorWindowController.h"
@@ -399,6 +398,7 @@
   [theItem setEnabled: YES];
   [theItem setTarget: self];
   [[imapSupportedMechanismsPopUp menu] addItem: theItem];
+  [theItem release];
   
   theArray = [store supportedMechanisms];
   
