@@ -2,9 +2,11 @@
 **  PGPController.m
 **
 **  Copyright (c) 2001-2006 Ludovic Marcotte, Tomio Arisaka
+**  Copyright (C) 2017      Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Tomio Arisaka <tomio-a@max.hi-ho.ne.jp>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -20,28 +22,28 @@
 **  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "PGPController.h"
-#include "PGPViewController.h"
+#import "PGPController.h"
+#import "PGPViewController.h"
 
 // GNUMail headers
-#include "Constants.h"
-#include "MailWindowController.h"
-#include "NSAttributedString+Extensions.h"
-#include "NSUserDefaults+Extensions.h"
-#include "PasswordPanelController.h"
-#include "Utilities.h"
+#import "Constants.h"
+#import "MailWindowController.h"
+#import "NSAttributedString+Extensions.h"
+#import "NSUserDefaults+Extensions.h"
+#import "PasswordPanelController.h"
+#import "Utilities.h"
 
 // Pantomime headers
-#include <Pantomime/CWConstants.h>
-#include <Pantomime/CWInternetAddress.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/CWMIMEMultipart.h>
-#include <Pantomime/CWMIMEUtility.h>
-#include <Pantomime/CWParser.h>
-#include <Pantomime/CWPart.h>
-#include <Pantomime/NSData+Extensions.h>
-#include <Pantomime/NSFileManager+Extensions.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWConstants.h>
+#import <Pantomime/CWInternetAddress.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWMIMEMultipart.h>
+#import <Pantomime/CWMIMEUtility.h>
+#import <Pantomime/CWParser.h>
+#import <Pantomime/CWPart.h>
+#import <Pantomime/NSData+Extensions.h>
+#import <Pantomime/NSFileManager+Extensions.h>
+#import <Pantomime/NSString+Extensions.h>
 
 static PGPController *singleInstance = nil;
 
@@ -175,35 +177,36 @@ static PGPController *singleInstance = nil;
 
 - (id) initWithOwner: (id) theOwner
 {
-  NSBundle *aBundle;
-  
   self = [super init];
-
-  owner = theOwner;
+  if (self)
+    {
+      NSBundle *aBundle;
+   
+      owner = theOwner;
  
-  aBundle = [NSBundle bundleForClass: [self class]];
+      aBundle = [NSBundle bundleForClass: [self class]];
   
-  resourcePath = [aBundle resourcePath];
-  RETAIN(resourcePath);
+      resourcePath = [aBundle resourcePath];
+      RETAIN(resourcePath);
 
-  sImage = [[NSImage alloc] initWithContentsOfFile: [NSString stringWithFormat: @"%@/signed_80.tiff", resourcePath]];
-  eImage = [[NSImage alloc] initWithContentsOfFile: [NSString stringWithFormat: @"%@/encrypted_80.tiff", resourcePath]];
-  seImage = [[NSImage alloc] initWithContentsOfFile: [NSString stringWithFormat: @"%@/signed+encrypted_80.tiff", resourcePath]];
+      sImage = [[NSImage alloc] initWithContentsOfFile: [NSString stringWithFormat: @"%@/signed_80.tiff", resourcePath]];
+      eImage = [[NSImage alloc] initWithContentsOfFile: [NSString stringWithFormat: @"%@/encrypted_80.tiff", resourcePath]];
+      seImage = [[NSImage alloc] initWithContentsOfFile: [NSString stringWithFormat: @"%@/signed+encrypted_80.tiff", resourcePath]];
   
-  view = [[PGPImageView alloc] init];
+      view = [[PGPImageView alloc] init];
 
-  // We create our passphrase cache
-  passphraseCache = [[NSMutableDictionary alloc] init];
+      // We create our passphrase cache
+      passphraseCache = [[NSMutableDictionary alloc] init];
 
-  [self updateAndRestartTimer];
-
-  // We register for our notification
-  [[NSNotificationCenter defaultCenter]
-    addObserver: self
-    selector: @selector(_messageFetchCompleted:)
-    name: @"PantomimeMessageFetchCompleted"
-    object: nil];
+      [self updateAndRestartTimer];
 
+      // We register for our notification
+      [[NSNotificationCenter defaultCenter]
+       addObserver: self
+       selector: @selector(_messageFetchCompleted:)
+       name: @"PantomimeMessageFetchCompleted"
+       object: nil];
+    }
   return self;
 }
 
