@@ -28,7 +28,7 @@
 #include "HeadersWindow.h"
 #endif
 
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/NSString+Extensions.h>
 
 static NSString *ShownHeadersPboardType = @"ShownHeadersPboardType";
 static NSArray *draggedShownHeaders;
