@@ -2,8 +2,10 @@
 **  AddressBookController.m
 **
 **  Copyright (c) 2003-2006 Ludovic Marcotte
+**  Copyright (C) 2018      Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -19,21 +21,21 @@
 **  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "AddressBookController.h"
+#import "AddressBookController.h"
 
-#include "AddressTaker.h"
+#import "AddressTaker.h"
 
 #ifndef MACOSX
-#include "AddressBookPanel.h"
+#import "AddressBookPanel.h"
 #endif
 
-#include "GNUMail.h"
-#include "Constants.h"
-#include "Utilities.h"
+#import "GNUMail.h"
+#import "Constants.h"
+#import "Utilities.h"
 
-#include <Pantomime/CWInternetAddress.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWInternetAddress.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/NSString+Extensions.h>
 
 #define AB_SEARCH_ELEMENT(class, property, prefix) \
   [class searchElementForProperty: property \
@@ -50,7 +52,7 @@ static AddressBookController *singleInstance = nil;
 @implementation NSArray (GNUMailABExtensions)
 - (BOOL) containsRecord: (ABRecord *) record
 {
-  int i;
+  NSUInteger i;
   
   i = [self count];
   
@@ -75,7 +77,7 @@ static AddressBookController *singleInstance = nil;
 {
   NSMutableArray *arr; ABMultiValue *emails;
   NSString *firstName, *lastName;
-  int i;
+  NSUInteger i;
 
   thePrefix = [thePrefix lowercaseString]; // only check to-lower
 
@@ -89,7 +91,7 @@ static AddressBookController *singleInstance = nil;
   arr = [NSMutableArray array];
   if (firstName && [[firstName lowercaseString] hasPrefix: thePrefix])
     {
-      for (i=0; i<[emails count]; i++)
+      for (i = 0; i < [emails count]; i++)
 	{
 	  if (lastName)
 	    {
@@ -108,7 +110,7 @@ static AddressBookController *singleInstance = nil;
   
   if (lastName && [[lastName lowercaseString] hasPrefix: thePrefix])
     {
-      for (i=0; i<[emails count]; i++)
+      for (i = 0; i < [emails count]; i++)
 	{
 	  if (firstName)
 	    {
@@ -125,7 +127,7 @@ static AddressBookController *singleInstance = nil;
       return [NSArray arrayWithArray: arr];
     }
   
-  for (i=0; i<[emails count]; i++)
+  for (i = 0; i < [emails count]; i++)
     {
       if ([[[emails valueAtIndex: i] lowercaseString] hasPrefix: thePrefix])
 	{
@@ -146,15 +148,15 @@ static AddressBookController *singleInstance = nil;
   if ( firstName && lastName )
     {
       return [NSString stringWithFormat: @"%@ %@ <%@>", firstName, lastName,
-		       [[self valueForProperty: kABEmailProperty] valueAtIndex: 0]];
+		       [(ABMultiValue *)[self valueForProperty: kABEmailProperty] valueAtIndex: 0]];
     }
   else if ( firstName || lastName )
     {
       return [NSString stringWithFormat: @"%@ <%@>", (firstName == nil ? lastName : firstName),
-		       [[self valueForProperty: kABEmailProperty] valueAtIndex: 0]];
+		       [(ABMultiValue *)[self valueForProperty: kABEmailProperty] valueAtIndex: 0]];
     }
   
-  return [[self valueForProperty: kABEmailProperty] valueAtIndex: 0];
+  return [(ABMultiValue *)[self valueForProperty: kABEmailProperty] valueAtIndex: 0];
 }
 
 - (NSString *) fullName
@@ -267,12 +269,12 @@ static AddressBookController *singleInstance = nil;
   ABMutableMultiValue *aMutableMultiValue;
 #ifdef MACOSX
   NSArray *allObjects, *allKeys;
-  int i, j;
+  NSUInteger i, j;
 #endif
   NSEnumerator *theEnumerator;
   ABPerson *aPerson;
   ABPerson *other;
-  int v;
+  NSUInteger v;
   
   personal = [[theMessage from] personal];
   email = [[theMessage from] address];
@@ -546,7 +548,7 @@ static AddressBookController *singleInstance = nil;
       ABPerson *aPerson;
       ABGroup *aGroup;
       
-      int i, j, count;
+      NSUInteger i, j, count;
 
       aMutableArray = NSMapGet(_table, theSubstring);
 
@@ -580,7 +582,7 @@ static AddressBookController *singleInstance = nil;
 	    {
 	      for (j = 0; j < [[aPerson valueForProperty: kABEmailProperty] count]; j++)
 		{
-		  [aMutableArray addObject: [[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]];
+		  [aMutableArray addObject: [(ABMultiValue *)[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]];
 		}
 	    }
 	  // We look at the addresses directly
@@ -588,10 +590,10 @@ static AddressBookController *singleInstance = nil;
 	    {
 	      for (j = 0; j < [[aPerson valueForProperty: kABEmailProperty] count]; j++)
 		{
-		  if ([theSubstring rangeOfString: [[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]
+		  if ([theSubstring rangeOfString: [(ABMultiValue *)[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]
 				    options: NSCaseInsensitiveSearch].length)
 		    {
-		      [aMutableArray addObject: [[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]];
+		      [aMutableArray addObject: [(ABMultiValue *)[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]];
 		    }
 		}
 	    }
@@ -689,7 +691,7 @@ static AddressBookController *singleInstance = nil;
   NSArray *allObjects, *allKeys;
   ABAddressBook *addressBook;
   ABPerson *aPerson;
-  int i, j;
+  NSUInteger i, j;
   
   addressBook = [ABAddressBook sharedAddressBook];
   [allPersons removeAllObjects];
@@ -711,7 +713,7 @@ static AddressBookController *singleInstance = nil;
       for (j = 0; j < [[aPerson valueForProperty: kABEmailProperty] count]; j++)
         {
           [allPersons setObject: aPerson
-                         forKey: [[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]];
+                         forKey: [(ABMultiValue *)[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]];
         }
     }
 
@@ -735,14 +737,14 @@ static AddressBookController *singleInstance = nil;
 }
 
 
-- (int) numberOfRowsInTableView: (NSTableView *) theTableView
+- (NSInteger) numberOfRowsInTableView: (NSTableView *) theTableView
 {
   return [allSortedKeys count];
 }
 
 - (id)           tableView: (NSTableView *) aTableView
  objectValueForTableColumn: (NSTableColumn *) aTableColumn 
-		       row: (int) rowIndex
+		       row: (NSInteger) rowIndex
 {
   ABPerson *aPerson;
   
@@ -765,7 +767,7 @@ static AddressBookController *singleInstance = nil;
 
 - (BOOL)  tableView: (NSTableView *) theTableView
 shouldEditTableColumn: (NSTableColumn *) theTableColumn
-                 row: (int) theRow
+                 row: (NSInteger) theRow
 {
   // We prevent any kind of editing in the table view
   return NO;
@@ -828,7 +830,7 @@ shouldEditTableColumn: (NSTableColumn *) theTableColumn
   
   if ([theValues count] > 0)
     { 
-      int i;
+      NSUInteger i;
            
       for (i = 0; i < [theValues count]; i++)
 	{
