@@ -2,6 +2,7 @@
 **  ApplicationIconController.m
 **
 **  Copyright (c) 2004-2007 Ludovic Marcotte
+**  Copyright (c) 2017      Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -19,23 +20,23 @@
 **  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "ApplicationIconController.h"
+#import "ApplicationIconController.h"
 
-#include <Pantomime/CWFolder.h>
-#include <Pantomime/CWStore.h>
-#include <Pantomime/CWIMAPStore.h>
-#include <Pantomime/CWLocalStore.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWFolder.h>
+#import <Pantomime/CWStore.h>
+#import <Pantomime/CWIMAPStore.h>
+#import <Pantomime/CWLocalStore.h>
+#import <Pantomime/NSString+Extensions.h>
 
-#include "Constants.h"
-#include "MailboxManagerCache.h"
-#include "MailboxManagerController.h"
+#import "Constants.h"
+#import "MailboxManagerCache.h"
+#import "MailboxManagerController.h"
 
 static ApplicationIconController *singleInstance;
 static NSMapTable *_cache;
 
 #ifndef GNUSTEP
-static int previous_unread_count = -1;
+static NSUInteger previous_unread_count = NSNotFound;
 #endif
 
 @interface UglyHack : NSObject
@@ -147,7 +148,7 @@ NSString* stringValueOfURLNameFromFolderName(NSString *folderName, id aStore)
 //
 //
 //
-int number_of_unread_messages()
+NSUInteger number_of_unread_messages()
 {
   NSArray *allFolders, *allKeys;
   MailboxManagerCache *cache;
@@ -156,7 +157,7 @@ int number_of_unread_messages()
   NSArray *inboxNames;
   BOOL inboxOnly;
 
-  unsigned int c, i, j, v, result;
+  NSUInteger c, i, j, v, result;
   
   cache = [[MailboxManagerController singleInstance] cache];
   allKeys = NSAllMapTableKeys(_cache);
@@ -216,40 +217,41 @@ int number_of_unread_messages()
   NSSize serverIconSize;
 
   self = [super init];
-
-  currentServer = [[[NSThread currentThread] threadDictionary] objectForKey:@"NSCurrentServerThreadKey"];
-  _icon = [NSImage imageNamed: @"GNUMail"];
-  [_icon setScalesWhenResized: YES];
-  if (currentServer && [currentServer respondsToSelector: @selector(iconSize)])
+  if (self)
     {
-      serverIconSize = [currentServer iconSize];
-      [_icon setSize: NSMakeSize(serverIconSize.width - (serverIconSize.width / 4),
-      				 serverIconSize.height - (serverIconSize.height / 4))];
-      _borderPoint = NSMakePoint(serverIconSize.width/8,serverIconSize.height/8);
-    }
-  else
-    {
-      serverIconSize = NSMakeSize(64,64);
-      [_icon setSize: NSMakeSize(56,56)];
-      _borderPoint = NSMakePoint(0, 4);
-    }
-  RETAIN(_icon);
+      currentServer = [[[NSThread currentThread] threadDictionary] objectForKey:@"NSCurrentServerThreadKey"];
+      _icon = [NSImage imageNamed: @"GNUMail"];
+      [_icon setScalesWhenResized: YES];
+      if (currentServer && [currentServer respondsToSelector: @selector(iconSize)])
+	{
+	  serverIconSize = [currentServer iconSize];
+	  [_icon setSize: NSMakeSize(serverIconSize.width - (serverIconSize.width / 4),
+				     serverIconSize.height - (serverIconSize.height / 4))];
+	  _borderPoint = NSMakePoint(serverIconSize.width/8,serverIconSize.height/8);
+	}
+      else
+	{
+	  serverIconSize = NSMakeSize(64,64);
+	  [_icon setSize: NSMakeSize(56,56)];
+	  _borderPoint = NSMakePoint(0, 4);
+	}
+      RETAIN(_icon);
 
-  _tile = nil;
+      _tile = nil;
 
-  if (currentServer && [currentServer respondsToSelector:@selector(iconTileImage)])
-    {
-      _tile = [[currentServer iconTileImage] copy];
-      [_tile setScalesWhenResized:YES];
-      [_tile setSize:serverIconSize];
+      if (currentServer && [currentServer respondsToSelector:@selector(iconTileImage)])
+	{
+	  _tile = [[currentServer iconTileImage] copy];
+	  [_tile setScalesWhenResized:YES];
+	  [_tile setSize:serverIconSize];
+	}
+      else
+	{
+	  _tile = [NSImage imageNamed: @"common_Tile"];
+	  RETAIN(_tile);
+	}
+      [self setFrame: NSMakeRect(0,0,serverIconSize.width,serverIconSize.height)];
     }
-  else
-    {
-      _tile = [NSImage imageNamed: @"common_Tile"];
-      RETAIN(_tile);
-    }
-  [self setFrame: NSMakeRect(0,0,serverIconSize.width,serverIconSize.height)];
-
   return self;
 }
 
@@ -267,7 +269,7 @@ int number_of_unread_messages()
 
 - (void) drawRect: (NSRect) theRect
 {
-  int v;
+  NSUInteger v;
 
   [_tile compositeToPoint: NSMakePoint(0,0)  operation: NSCompositeSourceAtop];
 
@@ -306,30 +308,33 @@ int number_of_unread_messages()
 {
   self = [super init];
   
-  _cache = NSCreateMapTable(NSObjectMapKeyCallBacks, NSObjectMapValueCallBacks, 16);
+  if (self)
+    {
+      _cache = NSCreateMapTable(NSObjectMapKeyCallBacks, NSObjectMapValueCallBacks, 16);
 
 #ifndef MACOSX
-  [[[NSApp iconWindow] contentView] addSubview: AUTORELEASE([[ApplicationIconView alloc] init])];
+      [[[NSApp iconWindow] contentView] addSubview: AUTORELEASE([[ApplicationIconView alloc] init])];
 #endif
 
-  [[NSNotificationCenter defaultCenter]
-    addObserver: self
-    selector: @selector(folderListCompleted:)
-    name: PantomimeFolderListCompleted
-    object: nil];
+      [[NSNotificationCenter defaultCenter]
+	addObserver: self
+	   selector: @selector(folderListCompleted:)
+	       name: PantomimeFolderListCompleted
+	     object: nil];
 
- [[NSNotificationCenter defaultCenter]
-    addObserver: self
-    selector: @selector(connectionTerminated:)
-    name: PantomimeConnectionTerminated
-    object: nil];
+      [[NSNotificationCenter defaultCenter]
+	addObserver: self
+	   selector: @selector(connectionTerminated:)
+	       name: PantomimeConnectionTerminated
+	     object: nil];
  
- [[NSNotificationCenter defaultCenter]
-    addObserver: self
-    selector: @selector(folderListCompleted:)
-    name: PantomimeFolderListSubscribedCompleted
-    object: nil];
-  
+      [[NSNotificationCenter defaultCenter]
+	addObserver: self
+	   selector: @selector(folderListCompleted:)
+	       name: PantomimeFolderListSubscribedCompleted
+	     object: nil];  
+    }
+
   return self;
 }
 
@@ -346,7 +351,8 @@ int number_of_unread_messages()
   for (u = 0; u < [keys count]; u++)
     [[keys objectAtIndex:u] release];
   [[NSNotificationCenter defaultCenter] removeObserver: self];
-  NSFreeMapTable(_cache);  
+  NSFreeMapTable(_cache);
+  _cache = nil;
   [super dealloc];
 }
 
@@ -359,14 +365,14 @@ int number_of_unread_messages()
   [[[NSApp iconWindow] contentView] setNeedsDisplay: YES];
 #else
   NSImage *image;
-  int v;
+  NSUInteger v;
   
   image = AUTORELEASE([[NSImage alloc] initWithContentsOfFile: [[NSBundle mainBundle] pathForImageResource: @"GNUMail_128"]]);
   [image lockFocus];
   
   v = number_of_unread_messages();
 
-  if (previous_unread_count != -1 && previous_unread_count < v)
+  if (previous_unread_count != NSNotFound && previous_unread_count < v)
     {
       [NSApp requestUserAttention: NSInformationalRequest];
     }
