@@ -21,8 +21,8 @@
 
 */
 
-#include "AutoCompletingTextField.h"
-#include "Constants.h"
+#import "AutoCompletingTextField.h"
+#import "Constants.h"
 
 static NSWindow *_sharedDropDown = nil;
 static NSScrollView *_sharedDropDownScrollView = nil;
