@@ -75,7 +75,7 @@ static NSImage *stop = nil;
 {
   NSString *aString;
   float f, w;
-  int i;
+  NSUInteger i;
 
   [super drawWithFrame: cellFrame  inView: controlView];
   
@@ -677,8 +677,8 @@ static NSImage *stop = nil;
 //
 - (void) reload
 {
-  int count;
-  int i;
+  NSUInteger count;
+  NSUInteger i;
   
   [tasksTableView reloadData];
   
@@ -708,7 +708,7 @@ static NSImage *stop = nil;
 - (void) restoreImage
 {
   MailWindowController *aController;
-  int count;
+  NSUInteger count;
 
   count = [[GNUMail allMailWindows] count];
   
@@ -752,7 +752,7 @@ static NSImage *stop = nil;
 
 - (void) _startAnimation
 {
-  unsigned int count;
+  NSUInteger count;
       
   count = [[GNUMail allMailWindows] count];
   
@@ -764,9 +764,9 @@ static NSImage *stop = nil;
 
 - (void) _startTask
 {
-  int count, row;
+  NSInteger count, row;
 
-  count = [[[TaskManager singleInstance] allTasks] count];
+  count = (NSInteger)[[[TaskManager singleInstance] allTasks] count];
   row = [tasksTableView selectedRow];
 
   if (row >= 0 && row < count)
@@ -786,7 +786,7 @@ static NSImage *stop = nil;
 - (void) _stopAnimation
 {
   MailWindowController *aController;
-  unsigned int count;
+  NSUInteger count;
   
   count = [[GNUMail allMailWindows] count];
   
@@ -802,9 +802,9 @@ static NSImage *stop = nil;
 
 - (void) _stopTask
 {
-  int count, row;
+  NSInteger count, row;
 
-  count = [[[TaskManager singleInstance] allTasks] count];
+  count = (NSInteger)[[[TaskManager singleInstance] allTasks] count];
   row = [tasksTableView selectedRow];
 
   if (row >= 0 && row < count)
