@@ -2,8 +2,10 @@
 **  Constants.h
 **
 **  Copyright (c) 2003-2007 Ludovic Marcotte
+**  Copyright (C) 2014-2018 Riccardo Mottola
 ** 
-**  Author: Ludovic Marcotte <ludovic@Sophos.ca>   
+**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -75,6 +77,14 @@ if (__value != __object) \
 #endif
 #endif
 
+//
+// Selector comparison as macro on older OS and runtime if available (10.5 Leopard or later)
+//
+#if !defined (GNUSTEP) &&  (MAC_OS_X_VERSION_MAX_ALLOWED <= MAC_OS_X_VERSION_10_4)
+#define sel_isEqual(selector1, selector2) (selector1 ==  selector2)
+#else
+#include <objc/runtime.h>
+#endif
 
 #ifdef DEBUG
 #define NSDebugLog(format, args...) \
