@@ -2,7 +2,7 @@
 **  EditWindowController.m
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
-**  Copyright (C) 2014-2015 Riccardo Mottola
+**  Copyright (C) 2014-2017 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -21,44 +21,44 @@
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "EditWindowController.h"
+#import "EditWindowController.h"
 
-#include "AddressBookController.h"
-#include "AutoCompletingTextField.h"
+#import "AddressBookController.h"
+#import "AutoCompletingTextField.h"
 
-#include "ExtendedMenuItem.h"
-#include "ExtendedTextAttachmentCell.h"
-#include "ExtendedTextView.h"
-#include "GNUMail.h"
-#include "GNUMailBundle.h"
-#include "Constants.h"
-#include "LabelWidget.h"
-#include "MailboxManagerController.h"
-#include "MailWindowController.h"
-#include "MimeTypeManager.h"
-#include "MimeType.h"
-#include "NSAttributedString+Extensions.h"
-#include "NSFont+Extensions.h"
-#include "NSUserDefaults+Extensions.h"
-#include "Task.h"
-#include "TaskManager.h"
-#include "Utilities.h"
+#import "ExtendedMenuItem.h"
+#import "ExtendedTextAttachmentCell.h"
+#import "ExtendedTextView.h"
+#import "GNUMail.h"
+#import "GNUMailBundle.h"
+#import "Constants.h"
+#import "LabelWidget.h"
+#import "MailboxManagerController.h"
+#import "MailWindowController.h"
+#import "MimeTypeManager.h"
+#import "MimeType.h"
+#import "NSAttributedString+Extensions.h"
+#import "NSFont+Extensions.h"
+#import "NSUserDefaults+Extensions.h"
+#import "Task.h"
+#import "TaskManager.h"
+#import "Utilities.h"
 
-#include <Pantomime/CWCharset.h>
-#include <Pantomime/CWConstants.h>
-#include <Pantomime/CWIMAPStore.h>
-#include <Pantomime/CWInternetAddress.h>
-#include <Pantomime/CWFlags.h>
-#include <Pantomime/CWLocalFolder.h>
-#include <Pantomime/CWLocalStore.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/CWMIMEMultipart.h>
-#include <Pantomime/CWMIMEUtility.h>
-#include <Pantomime/CWPart.h>
-#include <Pantomime/CWURLName.h>
-#include <Pantomime/CWService.h>
-#include <Pantomime/NSData+Extensions.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWCharset.h>
+#import <Pantomime/CWConstants.h>
+#import <Pantomime/CWIMAPStore.h>
+#import <Pantomime/CWInternetAddress.h>
+#import <Pantomime/CWFlags.h>
+#import <Pantomime/CWLocalFolder.h>
+#import <Pantomime/CWLocalStore.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWMIMEMultipart.h>
+#import <Pantomime/CWMIMEUtility.h>
+#import <Pantomime/CWPart.h>
+#import <Pantomime/CWURLName.h>
+#import <Pantomime/CWService.h>
+#import <Pantomime/NSData+Extensions.h>
+#import <Pantomime/NSString+Extensions.h>
 
 #include <math.h>
 #include <time.h>
@@ -97,7 +97,7 @@
 #define L_WIDTH 55
 
 #define Y_DELTA 25
-#define W_DELTA 75
+#define W_DELTA 79
 
 #define F_X 65
 #define F_HEIGHT 21
@@ -130,7 +130,7 @@
 - (NSString *) _loadSignature;
 
 - (void) _openPanelDidEnd: (NSOpenPanel *) theOpenPanel
-               returnCode: (int) theReturnCode
+               returnCode: (NSInteger) theReturnCode
               contextInfo: (void *) theContextInfo;
 
 - (void) _replaceSignature;
@@ -144,11 +144,11 @@
 
 #ifdef MACOSX
 - (void) _sheetDidEnd: (NSWindow *) sheet
-           returnCode: (int) returnCode
+           returnCode: (NSInteger) returnCode
           contextInfo: (void *) contextInfo;
 
 - (void) _sheetDidDismiss: (NSWindow *) sheet
-               returnCode: (int) returnCode
+               returnCode: (NSInteger) returnCode
               contextInfo: (void *) contextInfo;
 #endif
 
@@ -1156,7 +1156,7 @@
   CWInternetAddress *anInternetAddress;
   BOOL hasFoundUserAgentHeader;
   NSString *aString;
-  int i;
+  NSUInteger i;
   
   // We initialize our boolean value to false
   hasFoundUserAgentHeader = NO;
@@ -1493,6 +1493,24 @@
     }
 }
 
+//
+//
+//
+- (BOOL) validateMenuItem: (id<NSMenuItem>) theMenuItem
+{
+  SEL action;
+  
+  action = [theMenuItem action];
+  //
+  // Deliver / Send Message
+  //
+  if (sel_isEqual(action, @selector(sendMessage:)))
+    {
+      return YES;
+    }
+  return NO;
+}
+
 @end
 
 
@@ -1618,7 +1636,7 @@
   if (aString && [aString length])
     {
       // If there's a comma in the name, we quote the whole thing.
-      if ([aString indexOfCharacter: ','] >= 0)
+      if ([aString indexOfCharacter: ','] != NSNotFound)
 	{
 	  aString = [NSString stringWithFormat: @"\"%@\"", aString];
 	}
@@ -2017,7 +2035,7 @@
 //
 //
 - (void) _openPanelDidEnd: (NSOpenPanel *) theOpenPanel
-               returnCode: (int) theReturnCode
+               returnCode: (NSInteger) theReturnCode
               contextInfo: (void *) theContextInfo
 {
   if (theReturnCode == NSOKButton)
@@ -2154,7 +2172,7 @@
   NSTextStorage *textStorage;
 
   NSAutoreleasePool *pool;
-  int i, len;
+  NSUInteger i, len;
   
   textStorage = [textView textStorage];
 
@@ -2163,18 +2181,20 @@
   pool = [[NSAutoreleasePool alloc] init];
   len = [aMutableString length];
 
-  for (i = (len - 1); i >= 0; i--)
+  for (i = len; i > 0; i--)
     { 
       NSTextAttachment *aTextAttachment;     
       id cell;
- 
-      if ( [aMutableString characterAtIndex: i] != NSAttachmentCharacter )
+      NSUInteger charIndex;
+      
+      charIndex = i-1;
+      if ( [aMutableString characterAtIndex: charIndex] != NSAttachmentCharacter )
 	{
 	  continue;
 	}
 
       aTextAttachment = [textStorage attribute: NSAttachmentAttributeName
-				     atIndex: i
+				     atIndex: charIndex
 				     effectiveRange: NULL];
       
       cell = (ExtendedTextAttachmentCell *)[aTextAttachment attachmentCell];
@@ -2186,18 +2206,18 @@
 
       if ( cell && [cell part] && [[cell part] filename] )
 	{
-	  [aMutableString replaceCharactersInRange: NSMakeRange(i, 1)
+	  [aMutableString replaceCharactersInRange: NSMakeRange(charIndex, 1)
 			  withString: [NSString stringWithFormat: @"<%@>", [[cell part] filename]] ];
 	}
       else if ( [[[aTextAttachment fileWrapper] filename] lastPathComponent] )
 	{
-	  [aMutableString replaceCharactersInRange: NSMakeRange(i, 1)
+	  [aMutableString replaceCharactersInRange: NSMakeRange(charIndex, 1)
 			  withString: [NSString stringWithFormat: @"<%@>", [[[aTextAttachment fileWrapper] filename]
 									     lastPathComponent]] ];
 	}
       else
 	{
-	  [aMutableString replaceCharactersInRange: NSMakeRange(i, 1)
+	  [aMutableString replaceCharactersInRange: NSMakeRange(charIndex, 1)
 			  withString: @"<unknown>"];
 	}
     }
@@ -2383,7 +2403,7 @@
   else
     {
       NSString *aCharset;
-     
+      
       // We verify if we are using automatic charset detection (when it's nil)
       if (![self charset])
 	{
@@ -2419,7 +2439,7 @@
 	}
       
       [thePart setFormat: PantomimeFormatUnknown];
-      [thePart setCharset: aCharset];
+      [thePart setCharset: aCharset];      
       [thePart setContent: [theString dataUsingEncoding: [NSString encodingForCharset: [aCharset dataUsingEncoding: NSASCIIStringEncoding]]]];
     }
 }
@@ -2430,7 +2450,7 @@
 //
 #ifdef MACOSX
 - (void) _sheetDidEnd: (NSWindow *) sheet
-	   returnCode: (int) returnCode
+	   returnCode: (NSInteger) returnCode
 	  contextInfo: (void *) contextInfo
 {
   if ( returnCode == NSAlertAlternateReturn )
@@ -2445,7 +2465,7 @@
 // Only called under MacOS X
 //
 - (void) _sheetDidDismiss: (NSWindow *) sheet
-	       returnCode: (int) returnCode
+	       returnCode: (NSInteger) returnCode
 	      contextInfo: (void *) contextInfo
 {
   // We cancel the closing operation
