@@ -2,7 +2,7 @@
 **  FindWindowController.m
 **
 **  Copyright (c) 2001-2006 Ludovic Marcotte
-**  Copyright (C) 2014      Riccardo Mottola
+**  Copyright (C) 2014-2017 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -23,10 +23,6 @@
 
 #import "FindWindowController.h"
 
-#ifndef MACOSX
-#include "FindWindow.h"
-#endif
-
 #import "GNUMail.h"
 #import "ConsoleWindowController.h"
 #import "Constants.h"
@@ -64,42 +60,7 @@ static FindWindowController *singleInstance = nil;
 
 - (id) initWithWindowNibName: (NSString *) windowNibName
 {
-#ifdef MACOSX
   self = [super initWithWindowNibName: windowNibName];
-#else
-
-#ifdef __MINGW32__
-  FindWindowX *theWindow;
-  
-  theWindow = [[FindWindowX alloc] initWithContentRect: NSMakeRect(200,200,340,175)
-#else
-  FindWindow *theWindow;
-
-  theWindow = [[FindWindow alloc] initWithContentRect: NSMakeRect(200,200,340,175)
-#endif
-                                  styleMask: NSTitledWindowMask|NSClosableWindowMask|
-				  NSMiniaturizableWindowMask|NSResizableWindowMask
-				  backing: NSBackingStoreBuffered
-				  defer: YES];
-  
-  self = [super initWithWindow: theWindow];
-
-  [theWindow layoutWindow];
-  [theWindow setDelegate: self];
-  [theWindow setMinSize: [theWindow frame].size];
-
-  // We link our outlets
-  findField = theWindow->findField;
-  foundLabel = theWindow->foundLabel;
-  ignoreCaseButton = theWindow->ignoreCaseButton;
-  regularExpressionButton = theWindow->regularExpressionButton;
-  matrix = theWindow->matrix;
-  findAllButton = theWindow->findAllButton;
-  nextButton = theWindow->nextButton;
-  previousButton = theWindow->previousButton;
-
-  RELEASE(theWindow);
-#endif
 
   [[self window] setTitle: _(@"Find")];
 
