@@ -2,6 +2,7 @@
 **  FolderNode.m
 **
 **  Copyright (C) 2001-2004 Ludovic Marcotte
+**  Copyright (C) 2017      Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -28,14 +29,15 @@
 - (id) init
 {
   self = [super init];
- 
-  [self setChildren: nil];
+  if (self)
+    {
+      [self setChildren: nil];
 
-  _parent = nil;
-  _name = nil;
-  _path = nil;
-  _subscribed = NO;
- 
+      _parent = nil;
+      _name = nil;
+      _path = nil;
+      _subscribed = NO;
+    }
   return self;
 }
 
@@ -54,6 +56,7 @@
 //
 - (id) copyWithZone: (NSZone *) zone
 {
+#warning is this correct?
   return RETAIN(self);
 }
 
@@ -115,7 +118,7 @@
   
   if (theChildren)
     {
-      int i;
+      NSUInteger i;
 
       [aMutableArray addObjectsFromArray: theChildren];
 
@@ -147,7 +150,7 @@
 
 - (FolderNode *) childWithName: (NSString *) theName
 {
-  int i, count;
+  NSUInteger i, count;
 
   count = [_children count];
 
