@@ -2,8 +2,10 @@
 **  GNUMail+MenuValidation.m
 **
 **  Copyright (c) 2007 Ludovic Marcotte
+**  Copyright (C) 2018 Riccardo Mottola
 **
-**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**  Authors: Ludovic Marcotte <ludovic@Sophos.ca>
+**           Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -19,27 +21,29 @@
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "GNUMail+MenuValidation.h"
+#import "GNUMail+MenuValidation.h"
 
-#include "Constants.h"
-#include "EditWindowController.h"
-#include "MailWindowController.h"
+#import "Constants.h"
+#import "EditWindowController.h"
+#import "MailWindowController.h"
 
-#include <Pantomime/CWConstants.h>
-#include <Pantomime/CWFlags.h>
-#include <Pantomime/CWFolder.h>
-#include <Pantomime/CWMessage.h>
+#import <Pantomime/CWConstants.h>
+#import <Pantomime/CWFlags.h>
+#import <Pantomime/CWFolder.h>
+#import <Pantomime/CWMessage.h>
 
 @implementation GNUMail (MenuValidation)
 
 - (BOOL) validateMenuItem: (id<NSMenuItem>) theMenuItem
 {
   id aController;
-  id aMessage;
-
+  CWMessage *aMessage;
+  SEL action;
+  
   aController = [[GNUMail lastMailWindowOnTop] delegate];
   aMessage = nil;
-
+  action = [theMenuItem action];
+  
   if (aController)
     {
       if ([aController isKindOfClass: [MailWindowController class]] && [[aController dataView] numberOfSelectedRows] > 0)
@@ -51,82 +55,11 @@
 	  aMessage = [aController selectedMessage];
 	}
     }
-  
-  //
-  // Delete / Undelete message
-  //
-  if (theMenuItem == deleteOrUndelete)
-    {
-      if (!aMessage) return NO;
-
-      if ([[aMessage flags] contain: PantomimeDeleted])
-	{
-	  [deleteOrUndelete setTitle: _(@"Undelete")];
-	  [deleteOrUndelete setTag: UNDELETE_MESSAGE];
-	}
-      else
-	{
-	  [deleteOrUndelete setTitle: _(@"Delete")];
-	  [deleteOrUndelete setTag: DELETE_MESSAGE];
-	}
-    }
-  //
-  // Deliver
-  //
-  else if (theMenuItem == deliver)
-    {
-      if ([[[NSApp keyWindow] windowController] isKindOfClass: [EditWindowController class]])
-	{
-	  [theMenuItem setTarget: [[[NSApp orderedWindows] objectAtIndex: 0] windowController]];
-	  return YES;
-	}
-      else
-	{
-	  [theMenuItem setTarget: nil];
-	  return NO;
-	}
-    }
-  //
-  // Mark as Flagged / Unflagged
-  //
-  else if (theMenuItem == markAsFlaggedOrUnflagged)
-    {
-      if (!aMessage) return NO;
-
-      if ([[aMessage flags] contain: PantomimeFlagged])
-	{
-	  [markAsFlaggedOrUnflagged setTitle: _(@"Mark as Unflagged")];
-	  [markAsFlaggedOrUnflagged setTag: MARK_AS_UNFLAGGED];
-	}
-      else
-	{
-	  [markAsFlaggedOrUnflagged setTitle: _(@"Mark as Flagged")];
-	  [markAsFlaggedOrUnflagged setTag: MARK_AS_FLAGGED];
-	}   
-    }
-  //
-  // Mark as Read / Unread
-  //
-  else if (theMenuItem == markAsReadOrUnread)
-    {
-      if (!aMessage) return NO;
-      
-      if ([[aMessage flags] contain: PantomimeSeen])
-	{
-	  [markAsReadOrUnread setTitle: _(@"Mark as Unread")];
-	  [markAsReadOrUnread setTag: MARK_AS_UNREAD];
-	}
-      else
-	{
-	  [markAsReadOrUnread setTitle: _(@"Mark as Read")];
-	  [markAsReadOrUnread setTag: MARK_AS_READ];
-	}   
-    }
   //
   // Save in Drafts
-  else if (theMenuItem == saveInDrafts)
+  if (sel_isEqual(action, @selector(saveInDrafts:)))
     {
-      if ([[[NSApp keyWindow] windowController] isKindOfClass: [EditWindowController class]])
+      if ([[[NSApp keyWindow] windowController]  isKindOfClass: [EditWindowController class]])
 	{
 	  return YES;
 	}
@@ -137,55 +70,55 @@
   //
   // Show All Headers / Filtered
   //
-  else if (theMenuItem == showAllHeaders)
+  else if (sel_isEqual(action, @selector(showAllHeaders:)))
     {
       if (!aMessage) return NO;
 
       if ([aController showAllHeaders])
         {
-	  [showAllHeaders setTitle: _(@"Filtered Headers")];
-	  [showAllHeaders setTag: HIDE_ALL_HEADERS];
+	  [theMenuItem setTitle: _(@"Filtered Headers")];
+	  [theMenuItem setTag: HIDE_ALL_HEADERS];
         }
       else
         {
-	  [showAllHeaders setTitle: _(@"All Headers")];
-	  [showAllHeaders setTag: SHOW_ALL_HEADERS];
+	  [theMenuItem setTitle: _(@"All Headers")];
+	  [theMenuItem setTag: SHOW_ALL_HEADERS];
         }
     }
   //
   // Show / Hide Delete messages
   //
-  else if (theMenuItem == showOrHideDeleted)
+  else if (sel_isEqual(action, @selector(showOrHideDeletedMessages:)))
     {
       if (!aController) return NO;
 
       if ([[aController folder] showDeleted])
 	{
-	  [showOrHideDeleted setTitle: _(@"Hide Deleted")];
-	  [showOrHideDeleted setTag: HIDE_DELETED_MESSAGES];
+	  [theMenuItem setTitle: _(@"Hide Deleted")];
+	  [theMenuItem setTag: HIDE_DELETED_MESSAGES];
 	}
       else
 	{
-	  [showOrHideDeleted setTitle: _(@"Show Deleted")];
-	  [showOrHideDeleted setTag: SHOW_DELETED_MESSAGES];
+	  [theMenuItem setTitle: _(@"Show Deleted")];
+	  [theMenuItem setTag: SHOW_DELETED_MESSAGES];
 	}
     }
   //
   // Show / Hide Read messages
   // 
-  else if (theMenuItem == showOrHideRead)
+  else if (sel_isEqual(action, @selector(showOrHideReadMessages:)))
     {
       if (!aController) return NO;
       
       if ([[aController folder] showRead])
 	{
-	  [showOrHideRead setTitle: _(@"Hide Read")];
-	  [showOrHideRead setTag: HIDE_READ_MESSAGES];
+	  [theMenuItem setTitle: _(@"Hide Read")];
+	  [theMenuItem setTag: HIDE_READ_MESSAGES];
 	}
       else
 	{
-	  [showOrHideRead setTitle: _(@"Show Read")];
-	  [showOrHideRead setTag: SHOW_READ_MESSAGES];
+	  [theMenuItem setTitle: _(@"Show Read")];
+	  [theMenuItem setTag: SHOW_READ_MESSAGES];
 	}
     }
   //
@@ -217,17 +150,17 @@
   //
   // Show Raw Source / Normal Display
   //
-  else if (theMenuItem == showRawSource)
+  else if (sel_isEqual(action, @selector(showRawSource:)))
     {
       if (!aMessage) return NO;
 
       if ([aController showRawSource])
 	{
-	  [showRawSource setTitle: _(@"Normal Display")];
+	  [theMenuItem setTitle: _(@"Normal Display")];
 	}
       else
 	{
-	  [showRawSource setTitle: _(@"Raw Source")];
+	  [theMenuItem setTitle: _(@"Raw Source")];
 	}
     }
   //
@@ -239,14 +172,14 @@
 
       if ([[aController folder] allContainers])
 	{
-	  [threadOrUnthreadMessages setTitle: _(@"Unthread Messages")];
-	  [threadOrUnthreadMessages setTag: UNTHREAD_MESSAGES];
+	  [theMenuItem setTitle: _(@"Unthread Messages")];
+	  [theMenuItem setTag: UNTHREAD_MESSAGES];
 	  [selectAllMessagesInThread setAction: @selector(selectAllMessagesInThread:)];
 	}
       else
 	{
-	  [threadOrUnthreadMessages setTitle: _(@"Thread Messages")];
-	  [threadOrUnthreadMessages setTag: THREAD_MESSAGES];
+	  [theMenuItem setTitle: _(@"Thread Messages")];
+	  [theMenuItem setTag: THREAD_MESSAGES];
 	  [selectAllMessagesInThread setAction: NULL];
 	}
     }
