@@ -2,7 +2,7 @@
 **  MailWindowController.h
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
-**  Copyright (C) 2015      Riccardo Mottola
+**  Copyright (C) 2015-2018 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -78,6 +78,8 @@
   IBOutlet NSTableColumn *sizeColumn;
 
   IBOutlet NSMenu *menu;
+  IBOutlet NSMenuItem *markAsReadOrUnreadContextMI;
+  IBOutlet NSMenuItem *markAsFlaggedOrUnflaggedContextMI;
   IBOutlet NSDrawer *drawer;
   IBOutlet ExtendedOutlineView *outlineView;
 
@@ -142,6 +144,9 @@
 
 - (IBAction) viewMessageInWindow: (id) sender;
 
+- (IBAction) markMessageAsReadOrUnread: (id) sender;
+- (IBAction) markMessageAsFlaggedOrUnflagged: (id) sender;
+
 - (IBAction) getNewMessages: (id) sender;
 
 - (IBAction) copyOrMoveMessages: (id) sender;
