@@ -2,7 +2,7 @@
 **  MailWindowController.m
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
-**  Copyright (C) 2014-2016 Riccardo Mottola
+**  Copyright (C) 2014-2018 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -159,7 +159,7 @@
 							  @"forward",
 							  @"addresses",
 							  @"find",
-                              @"fastfind",
+                                                          @"fastfind",
 							  @"navigation",
 							  nil];
 
@@ -448,7 +448,7 @@
       CWFlags *theFlags;
       NSNumber *aRow;
 
-      int i, last_row, first_row;
+      NSInteger i, last_row, first_row;
       BOOL firstFlagOfList;
       
       selectedRows = [[dataView selectedRowEnumerator] allObjects];
@@ -532,7 +532,7 @@
       // If we're in reverse order, we select the previous row, otherwise, the next one.
       if (sender == delete || sender == self || [sender isKindOfClass: [ExtendedWindow class]])
 	{
-	  int count, row_to_select;
+	  NSInteger count, row_to_select;
 	  
 	  count = [dataView numberOfRows];
 	  row_to_select = last_row;
@@ -625,7 +625,7 @@
 //
 - (IBAction) nextMessage: (id) sender
 {
-  int row;
+  NSInteger row;
   
   row = [dataView selectedRow];
   
@@ -797,7 +797,7 @@
 //
 - (IBAction) previousMessage: (id) sender
 {
-  int row;
+  NSInteger row;
 
   row = [dataView selectedRow];
   
@@ -904,6 +904,97 @@
 
 }
 
+//
+//
+//
+- (IBAction) markMessageAsReadOrUnread: (id) sender
+{
+  NSEnumerator *anEnumerator;
+  CWMessage *aMessage;
+    
+  // We mark our message as read (or not)
+  anEnumerator = [[self selectedMessages] objectEnumerator];
+    
+  while ((aMessage = [anEnumerator nextObject]))
+    {
+      // If we must mark all messages as read
+      if ([sender tag] == MARK_AS_READ)
+        {
+          if (![[aMessage flags] contain: PantomimeSeen])
+            {
+              CWFlags *theFlags;
+                  
+              theFlags = [[aMessage flags] copy];
+              [theFlags add: PantomimeSeen];
+              [aMessage setFlags: theFlags];
+              RELEASE(theFlags);
+            }
+        }
+      // Else, we must mark them all as unread
+      else
+        {
+          if ([[aMessage flags] contain: PantomimeSeen])
+            {
+              CWFlags *theFlags;
+                  
+              theFlags = [[aMessage flags] copy];
+              [theFlags remove: PantomimeSeen];
+              [aMessage setFlags: theFlags];
+              RELEASE(theFlags);
+            }
+        }
+      } // while (...)
+    
+  // We always refresh our dataView and our status label
+  [[self dataView] setNeedsDisplay: YES];
+  [self updateStatusLabel];
+}
+
+//
+//
+//
+- (IBAction) markMessageAsFlaggedOrUnflagged: (id) sender
+{
+  NSEnumerator *anEnumerator;
+  CWMessage *aMessage;
+    
+  // We mark our message as flagged (or not)
+  anEnumerator = [[self selectedMessages] objectEnumerator];
+    
+  while ((aMessage = [anEnumerator nextObject]))
+    {
+      // If we must mark all messages as flagged
+      if ([sender tag] == MARK_AS_FLAGGED)
+        {
+          if ( ![[aMessage flags] contain: PantomimeFlagged] )
+            {
+              CWFlags *theFlags;
+                  
+              theFlags = [[aMessage flags] copy];
+              [theFlags add: PantomimeFlagged];
+              [aMessage setFlags: theFlags];
+              RELEASE(theFlags);
+            }
+        }
+        // Else, we must mark them all as unflagged
+      else
+        {
+          if ([[aMessage flags] contain: PantomimeFlagged])
+            {
+              CWFlags *theFlags;
+                  
+              theFlags = [[aMessage flags] copy];
+              [theFlags remove: PantomimeFlagged];
+              [aMessage setFlags: theFlags];
+              RELEASE(theFlags);
+            }
+        }
+      } // while (...)
+    
+  // We always refresh our dataView and our status label
+  [[self dataView] setNeedsDisplay: YES];
+  [self updateStatusLabel];
+}
 
 //
 // This method returns the folder associated to this MailWindow.
@@ -1519,7 +1610,7 @@
       toPasteboard: (NSPasteboard *) pboard
 {
   NSMutableArray *propertyList;
-  int i, count;
+  NSInteger i, count;
 
   propertyList = [[NSMutableArray alloc] initWithCapacity: [rows count]];
   count = [rows count];
@@ -1601,7 +1692,7 @@
   NSMutableArray *allMessages;
   CWFolder *aSourceFolder;
   NSArray *propertyList;
-  int i, count;
+  NSInteger i, count;
   
   if ([info draggingSource] == dataView)
     {
@@ -1655,7 +1746,7 @@
   NSString *cellStringVal;
   NSArray *columns;
 
-  int row, col, numRows, numCols, initialRow, boundaryRow, rowIncrement;
+  NSInteger row, col, numRows, numCols, initialRow, boundaryRow, rowIncrement;
   
   if ( [[theString stringByTrimmingWhiteSpaces] length] == 0 )
     {
@@ -1711,7 +1802,7 @@
   NSMutableArray *visibleTableColumns;
   NSMutableDictionary *columnWidth;
   NSString *theIdentifier;
-  int i, count;
+  NSInteger i, count;
 
   //
   // We save the table columns order and width.
@@ -1949,35 +2040,39 @@
 
   // We set up our context menu
   menu = [[NSMenu alloc] init];
-  [menu setAutoenablesItems: NO];
+  [menu setAutoenablesItems: YES];
   
   aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"Add Sender to Address Book") action: @selector(addSenderToAddressBook:)  keyEquivalent: @""];
   [aMenuItem setTarget: [NSApp delegate]];
   [menu addItem: aMenuItem];
   RELEASE(aMenuItem);
-
+    
   aMenu = [[NSMenu alloc] init];
-  aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"List-Id")  action: @selector(makeFilterFromListId:)  keyEquivalent: @""];
-  [aMenuItem setTarget: [NSApp delegate]];
-  [aMenu addItem: aMenuItem];
-  RELEASE(aMenuItem);
-  
   aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"Sender") action: @selector(makeFilterFromSender:) keyEquivalent: @""];
   [aMenuItem setTarget: [NSApp delegate]];
   [aMenu addItem: aMenuItem];
   RELEASE(aMenuItem);
 
+  aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"To") action: @selector(makeFilterFromTo:) keyEquivalent: @""];
+  [aMenuItem setTarget: [NSApp delegate]];
+  [aMenu addItem: aMenuItem];
+  RELEASE(aMenuItem);
+    
+  aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"Cc") action: @selector(makeFilterFromCc:) keyEquivalent: @""];
+  [aMenuItem setTarget: [NSApp delegate]];
+  [aMenu addItem: aMenuItem];
+  RELEASE(aMenuItem);
+    
+  aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"List-Id")  action: @selector(makeFilterFromListId:)  keyEquivalent: @""];
+  [aMenuItem setTarget: [NSApp delegate]];
+  [aMenu addItem: aMenuItem];
+  RELEASE(aMenuItem);
+  
   aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"Subject") action: @selector(makeFilterFromSubject:) keyEquivalent: @""];
   [aMenuItem setTarget: [NSApp delegate]];
   [aMenu addItem: aMenuItem];
   RELEASE(aMenuItem);
 
-  aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"Make Filter from") action: NULL keyEquivalent: @""];
-  [menu addItem: aMenuItem];
-  [menu setSubmenu: aMenu forItem: aMenuItem];
-  RELEASE(aMenuItem);
-  RELEASE(aMenu);
-
   aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"Reply") action: @selector(replyToMessage:)  keyEquivalent: @""];
   [aMenuItem setTarget: self];
   [aMenuItem setTag: PantomimeNormalReplyMode];
@@ -2006,6 +2101,26 @@
   [aMenuItem setTarget: [NSApp delegate]];
   [menu addItem: aMenuItem];
   RELEASE(aMenuItem);
+
+  aMenuItem = [[NSMenuItem alloc] initWithTitle: _(@"Make Filter from") action: NULL keyEquivalent: @""];
+  [menu addItem: aMenuItem];
+  [menu setSubmenu: aMenu forItem: aMenuItem];
+  RELEASE(aMenuItem);
+  RELEASE(aMenu);
+  
+  markAsReadOrUnreadContextMI = [[NSMenuItem alloc] init];
+  [markAsReadOrUnreadContextMI setTitle: _(@"Mark as Unread")];
+  [markAsReadOrUnreadContextMI setAction: @selector(markMessageAsReadOrUnread:)];
+  [markAsReadOrUnreadContextMI setTarget: self];
+  [menu addItem: markAsReadOrUnreadContextMI];
+  RELEASE(markAsReadOrUnreadContextMI);
+  
+  markAsFlaggedOrUnflaggedContextMI = [[NSMenuItem alloc] init];
+  [markAsFlaggedOrUnflaggedContextMI setTitle: _(@"Mark as Flagged")];
+  [markAsFlaggedOrUnflaggedContextMI setAction: @selector(markMessageAsFlaggedOrUnflagged:)];
+  [markAsFlaggedOrUnflaggedContextMI setTarget: self];
+  [menu addItem: markAsFlaggedOrUnflaggedContextMI];
+  RELEASE(markAsFlaggedOrUnflaggedContextMI);
   
   //
   // Now let's add our Copy To / Move To menus and their respective items.
@@ -2130,7 +2245,7 @@
 //
 - (void) windowDidBecomeKey: (NSNotification *) aNotification
 {
-  int i;
+  NSUInteger i;
   
   // We set the last window on top
   [GNUMail setLastMailWindowOnTop: [self window]];
@@ -2576,8 +2691,9 @@
   Task *aTask;
   id anObject;
 
-  NSInteger totalSize, unreadCount, unreadSize, selectedSize, deletedCount, deletedSize;
-  NSInteger i, count, aSize, numberOfSelectedRows;
+  NSUInteger totalSize, unreadSize, selectedSize, deletedSize;
+  NSString *totalSizeStr, *unreadSizeStr, *selectedSizeStr, *deletedSizeStr;
+  NSUInteger i, count, unreadCount, deletedCount, aSize, numberOfSelectedRows;
   unsigned char aSeparator;
 
   if ([_folder isKindOfClass: [CWIMAPFolder class]] && 
@@ -2626,12 +2742,42 @@
 	    }
 	}
     }
-   
-  UPDATE_STATUS_LABEL(_(@"%d messages (%dKB) - %d unread (%dKB) - %d selected (%0.1fKB) - %d deleted (%0.1fKB)"),
-		      count, (totalSize/1024),
-		      unreadCount, (unreadSize/1024), 
-		      numberOfSelectedRows, ((float)selectedSize/(float)1024),
-		      deletedCount, ((float)deletedSize/(float)1024));
+  
+  if (totalSize < 1024)
+    totalSizeStr = [NSString stringWithFormat:@"%luB", (unsigned long) totalSize];
+  else if (totalSize < 1024 * 1024)
+    totalSizeStr = [NSString stringWithFormat:@"%0.1fKB", (float) totalSize / 1024];
+  else if (totalSize < 1024 * 1024 * 1024)
+    totalSizeStr = [NSString stringWithFormat:@"%0.1fMB", (float) totalSize / (1024 * 1024)];
+  else
+    totalSizeStr = [NSString stringWithFormat:@"%0.1fGB", (float) totalSize / (1024 * 1024 * 1024)];
+
+  if (unreadSize < 1024)
+    unreadSizeStr = [NSString stringWithFormat:@"%luB", (unsigned long) unreadSize];
+  else if (unreadSize < 1024 * 1024)
+    unreadSizeStr = [NSString stringWithFormat:@"%0.1fKB", (float) unreadSize / 1024];
+  else
+    unreadSizeStr = [NSString stringWithFormat:@"%0.1fMB", (float) unreadSize / (1024 * 1024)];
+  
+  if (selectedSize < 1024)
+    selectedSizeStr = [NSString stringWithFormat:@"%luB", (unsigned long) selectedSize];
+  else if (selectedSize < 1024 * 1024)
+    selectedSizeStr = [NSString stringWithFormat:@"%0.1fKB", (float) selectedSize / 1024];
+  else
+    selectedSizeStr = [NSString stringWithFormat:@"%0.1fMB", (float) selectedSize / (1024 * 1024)];
+
+  if (deletedSize < 1024)
+    deletedSizeStr = [NSString stringWithFormat:@"%luB", (unsigned long) deletedSize];
+  else if (deletedSize < 1024 * 1024)
+    deletedSizeStr = [NSString stringWithFormat:@"%0.1fKB", (float) deletedSize / 1024];
+  else
+    deletedSizeStr = [NSString stringWithFormat:@"%0.1fMB", (float) deletedSize / (1024 * 1024)];
+  
+  UPDATE_STATUS_LABEL(_(@"%lu messages (%@) - %lu unread (%@) - %lu selected (%@) - %lu deleted (%@)"),
+		      (unsigned long)count, totalSizeStr,
+		      (unsigned long)unreadCount, unreadSizeStr, 
+		      (unsigned long)numberOfSelectedRows, selectedSizeStr,
+		      (unsigned long)deletedCount,deletedSizeStr);
 
   [[ApplicationIconController singleInstance] update];
 
@@ -2772,6 +2918,80 @@
   [self doFind: searchField]; 
 }
 
+//
+//
+//
+- (BOOL) validateMenuItem: (id<NSMenuItem>) theMenuItem
+{
+  CWMessage *aMessage;
+  SEL action;
+    
+  aMessage = [self selectedMessage];
+  action = [theMenuItem action];
+  //
+  // Delete / Undelete message
+  //
+  if (sel_isEqual(action, @selector(deleteMessage:)))
+    {
+      if (nil == aMessage) return NO;
+      
+      if ([[aMessage flags] contain: PantomimeDeleted])
+	{
+	  [theMenuItem setTitle: _(@"Undelete")];
+	  [theMenuItem setTag: UNDELETE_MESSAGE];
+	}
+      else
+	{
+	  [theMenuItem setTitle: _(@"Delete")];
+	  [theMenuItem setTag: DELETE_MESSAGE];
+	}
+    }
+  //
+  // Deliver / Send Message
+  //
+  else if (sel_isEqual(action, @selector(sendMessage:)))
+    {
+      return NO;
+    }
+  //
+  // Mark as Flagged / Unflagged
+  //
+  else if (sel_isEqual(action, @selector(markMessageAsFlaggedOrUnflagged:)))
+    {
+      if (nil == aMessage) return NO;
+      
+      if ([[aMessage flags] contain: PantomimeFlagged])
+	{
+	  [theMenuItem setTitle: _(@"Mark as Unflagged")];
+	  [theMenuItem setTag: MARK_AS_UNFLAGGED];
+	}
+      else
+	{
+	  [theMenuItem setTitle: _(@"Mark as Flagged")];
+	  [theMenuItem setTag: MARK_AS_FLAGGED];
+	}   
+    }  
+  //
+  // Mark as Read / Unread
+  //
+  else if (sel_isEqual(action, @selector(markMessageAsReadOrUnread:)))
+    {
+      if (nil == aMessage) return NO;
+      
+      if ([[aMessage flags] contain: PantomimeSeen])
+	{
+	  [theMenuItem setTitle: _(@"Mark as Unread")];
+	  [theMenuItem setTag: MARK_AS_UNREAD];
+	}
+      else
+	{
+	  [theMenuItem setTitle: _(@"Mark as Read")];
+	  [theMenuItem setTag: MARK_AS_READ];
+	}   
+    }
+  return YES;
+}
+
 @end
 
 
@@ -3239,7 +3459,7 @@
   CWInternetAddress *aInternetAddress;
   NSMutableArray *allAddresses;
   CWMessage *aMessage;
-  int i;
+  NSUInteger i;
 
   allAddresses = AUTORELEASE([[NSMutableArray alloc] init]);
   aMessage = [_allMessages objectAtIndex: index];
@@ -3250,7 +3470,27 @@
     }
   else
     {
+      NSArray *recipients;
+      NSUInteger i;
+      BOOL isList;
+      
       [allAddresses addObject: [aMessage from]];
+
+      isList = NO;
+      if ([aMessage headerValueForName:@"List-Post"] != nil)
+        isList = YES;
+      
+      // now add only CC addresses, TO only if we think it is a list not "myself"
+      recipients = [aMessage recipients];
+      for (i = 0; i < [recipients count]; i++)
+        {
+          CWInternetAddress *recipient = [recipients objectAtIndex:i];
+
+          if ([recipient type] == PantomimeCcRecipient)
+            [allAddresses addObject:recipient];
+          else if (isList && [recipient type] == PantomimeToRecipient)
+            [allAddresses addObject:recipient];
+        }
     }
   
   for (i = 0; i < [allAddresses count]; i++)
