@@ -2,8 +2,10 @@
 **  MailboxManagerController.m
 **
 **  Copyright (C) 2001-2007 Ludovic Marcotte
+**  Copyright (c) 2017-2018 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -19,47 +21,46 @@
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "MailboxManagerController.h"
+#import "MailboxManagerController.h"
 
-#include "ConsoleWindowController.h"
-#include "Constants.h"
-#include "EditWindowController.h"
-#include "ExtendedMenuItem.h"
-#include "ExtendedOutlineView.h"
-#include "Filter.h"
-#include "FilterManager.h"
-#include "GNUMail.h"
-#include "Task.h"
-#include "TaskManager.h"
+#import "ConsoleWindowController.h"
+#import "Constants.h"
+#import "EditWindowController.h"
+#import "ExtendedMenuItem.h"
+#import "ExtendedOutlineView.h"
+#import "Filter.h"
+#import "FilterManager.h"
+#import "GNUMail.h"
+#import "Task.h"
+#import "TaskManager.h"
 
 #ifndef MACOSX
-#include "ImageTextCell.h"
-#include "MailboxManager.h"
+#import "ImageTextCell.h"
+#import "MailboxManager.h"
 #endif
 
-#include "FolderNode.h"
-#include "MailboxManagerCache.h"
-#include "MailWindowController.h"
-#include "MessageViewWindowController.h"
-#include "NewMailboxPanelController.h"
-#include "NSUserDefaults+Extensions.h"
-#include "Utilities.h"
+#import "FolderNode.h"
+#import "MailboxManagerCache.h"
+#import "MailWindowController.h"
+#import "MessageViewWindowController.h"
+#import "NewMailboxPanelController.h"
+#import "NSUserDefaults+Extensions.h"
+#import "Utilities.h"
 
-#include <Pantomime/CWConstants.h>
-#include <Pantomime/CWFlags.h>
-#include <Pantomime/CWFolderInformation.h>
-#include <Pantomime/CWIMAPCacheManager.h>
-#include <Pantomime/CWIMAPFolder.h>
-#include <Pantomime/CWIMAPStore.h>
-#include <Pantomime/CWLocalCacheManager.h>
-#include <Pantomime/CWLocalFolder.h>
-#include <Pantomime/CWLocalStore.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/CWTCPConnection.h>
-#include <Pantomime/CWURLName.h>
-#include <Pantomime/CWVirtualFolder.h>
-#include <Pantomime/NSData+Extensions.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWConstants.h>
+#import <Pantomime/CWFlags.h>
+#import <Pantomime/CWFolderInformation.h>
+#import <Pantomime/CWIMAPCacheManager.h>
+#import <Pantomime/CWIMAPFolder.h>
+#import <Pantomime/CWIMAPStore.h>
+#import <Pantomime/CWLocalFolder.h>
+#import <Pantomime/CWLocalStore.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWTCPConnection.h>
+#import <Pantomime/CWURLName.h>
+#import <Pantomime/CWVirtualFolder.h>
+#import <Pantomime/NSData+Extensions.h>
+#import <Pantomime/NSString+Extensions.h>
 
 #include <limits.h>
 
@@ -94,8 +95,8 @@ static MailboxManagerController *singleInstance = nil;
 - (void) _folderSubscribeCompleted: (NSNotification *) theNotification;
 - (void) _folderUnsubscribeCompleted: (NSNotification *) theNotification;
 - (BOOL) _initializeIMAPStoreWithAccountName: (NSString *) theAccountName;
-- (void) _nbOfMessages: (unsigned int *) theNbOfMessages
-    nbOfUnreadMessages: (unsigned int *) theNbOfUnreadMessages
+- (void) _nbOfMessages: (NSUInteger *) theNbOfMessages
+    nbOfUnreadMessages: (NSUInteger *) theNbOfUnreadMessages
                forItem: (id) theItem;
 - (void) _openLocalFolderWithName: (NSString *) theFolderName
                            sender: (id) theSender;
@@ -196,10 +197,12 @@ static MailboxManagerController *singleInstance = nil;
 - (id) init
 {
   self = [super init];
-  
-  // We initialize some ivars
-  [self windowDidLoad];
-  
+  if (self)
+    {
+      // We initialize some ivars
+      [self windowDidLoad];
+    }
+
   return self;
 }
 #endif
@@ -329,7 +332,7 @@ static MailboxManagerController *singleInstance = nil;
       
       if ([item childCount] == 0 || !b)
 	{
-	  unsigned int nbOfMessages, nbOfUnreadMessages;
+	  NSUInteger nbOfMessages, nbOfUnreadMessages;
 	  
 	  [self _nbOfMessages: &nbOfMessages
 		nbOfUnreadMessages: &nbOfUnreadMessages
@@ -340,8 +343,8 @@ static MailboxManagerController *singleInstance = nil;
 
 	  if ([[[tableColumn headerCell] stringValue] isEqual: _(@"Messages")])
 	    {
-	      if (nbOfUnreadMessages > 0) return [NSString stringWithFormat: @"(%d) %d", nbOfUnreadMessages, nbOfMessages];
-	      return [NSString stringWithFormat: @"%d", nbOfMessages];
+	      if (nbOfUnreadMessages > 0) return [NSString stringWithFormat: @"(%lu) %lu", (unsigned long)nbOfUnreadMessages, (unsigned long)nbOfMessages];
+	      return [NSString stringWithFormat: @"%lu", (unsigned long)nbOfMessages];
 	    }
 	}
     }
@@ -437,7 +440,7 @@ static MailboxManagerController *singleInstance = nil;
  shouldEditTableColumn: (NSTableColumn *) theTableColumn
 		  item: (id) theItem
 {
-  int row, level;
+  NSInteger row, level;
   id item;
 
   row = [theOutlineView selectedRow];
@@ -470,7 +473,7 @@ static MailboxManagerController *singleInstance = nil;
   // We set our default node icon, if we need to.
   if ([[[aTableColumn headerCell] stringValue] isEqual: _(@"Mailbox")])
     {
-      int level;
+      NSInteger level;
       
       level = [aOutlineView levelForItem: item];
       
@@ -490,8 +493,9 @@ static MailboxManagerController *singleInstance = nil;
 	    }
 #endif
 
+	  aStore = nil;
 	  aString = [self _stringValueOfURLNameFromItem: item
-			  store: &aStore];
+						  store: &aStore];
 
 	  if ([Utilities stringValueOfURLName: aString  isEqualTo: @"TRASHFOLDERNAME"])
 	    {
@@ -525,7 +529,7 @@ static MailboxManagerController *singleInstance = nil;
   //
   if ([item isKindOfClass: [FolderNode class]] && [item parent])
     {
-      unsigned int nbOfMessages, nbOfUnreadMessages;
+      NSUInteger nbOfMessages, nbOfUnreadMessages;
       
       [self _nbOfMessages: &nbOfMessages
 	    nbOfUnreadMessages: &nbOfUnreadMessages
@@ -602,7 +606,7 @@ static MailboxManagerController *singleInstance = nil;
 //
 - (BOOL) validateMenuItem: (NSMenuItem *) theItem
 {
-  int row, level;
+  NSInteger row, level;
   BOOL aBOOL;
   
   row = [outlineView selectedRow];
@@ -764,12 +768,6 @@ static MailboxManagerController *singleInstance = nil;
 	(CWFolder *)[(CWLocalStore *)aDestinationStore folderForName:
 								aFolderName];
 
-      if (![aDestinationFolder cacheManager])
-	{
-	  [aDestinationFolder setCacheManager: [[[CWLocalCacheManager alloc] initWithPath: [NSString stringWithFormat: @"%@.%@.cache", [[(CWLocalStore *)aDestinationFolder path] substringToIndex: ([[(CWLocalStore *)aDestinationFolder path] length] - [[[(CWLocalStore *)aDestinationFolder path] lastPathComponent] length])], [[(CWLocalStore *)aDestinationFolder path] lastPathComponent]]  folder: aDestinationFolder] autorelease]];
-	  [[aDestinationFolder cacheManager] initInRange: NSMakeRange(0, UINT_MAX)];
-	  [(CWLocalFolder *)aDestinationFolder parse: NO];
-	}
     }
 
   if (!aDestinationFolder)
@@ -1070,7 +1068,7 @@ static MailboxManagerController *singleInstance = nil;
 - (IBAction) open: (id) sender
 {
   id item;
-  int row, level;
+  NSInteger row, level;
   
   row = [outlineView selectedRow];
 
@@ -1326,7 +1324,7 @@ static MailboxManagerController *singleInstance = nil;
 //
 - (IBAction) rename: (id) sender
 {
-  int row;
+  NSInteger row;
 
   row = [outlineView selectedRow];
 
@@ -1493,13 +1491,6 @@ static MailboxManagerController *singleInstance = nil;
   else
     {
       aFolder = [(CWLocalStore *)aStore folderForName: [theURLName foldername]];
-
-      if (![aFolder cacheManager])
-	{
-	  [aFolder setCacheManager: [[[CWLocalCacheManager alloc] initWithPath: [NSString stringWithFormat: @"%@.%@.cache", [[aFolder path] substringToIndex: ([[aFolder path] length] - [[[aFolder path] lastPathComponent] length])], [[aFolder path] lastPathComponent]]  folder: aFolder] autorelease]];
-	  [[aFolder cacheManager] initInRange: NSMakeRange(0, UINT_MAX)];
-	  [(CWLocalFolder *)aFolder parse: NO];
-	}
     }
 
   return aFolder;
@@ -1604,13 +1595,6 @@ static MailboxManagerController *singleInstance = nil;
 
   aFolder = [aLocalStore folderForName: @"Panic"];
 
-  if (![aFolder cacheManager])
-    {
-      [aFolder setCacheManager: [[[CWLocalCacheManager alloc] initWithPath: [NSString stringWithFormat: @"%@.%@.cache", [[aFolder path] substringToIndex: ([[aFolder path] length] - [[[aFolder path] lastPathComponent] length])], [[aFolder path] lastPathComponent]]  folder: aFolder] autorelease]];
-      [[aFolder cacheManager] initInRange: NSMakeRange(0, UINT_MAX)];
-      [aFolder parse: NO];
-    }
-
   [aFolder appendMessageFromRawSource: theData  flags: nil];
 }
 
@@ -1694,7 +1678,7 @@ static MailboxManagerController *singleInstance = nil;
     }
   NS_HANDLER
     {
-
+      NSDebugLog(@"Exception while restoring Unsent Messages");
     }
   NS_ENDHANDLER;
 }
@@ -2138,7 +2122,7 @@ static MailboxManagerController *singleInstance = nil;
       CWMessage *aMessage;
       NSData *aData;
       Task *aTask;
-      int i;
+      NSUInteger i;
 	
       messagesToLoad = [NSMutableArray array];
 
@@ -2250,7 +2234,7 @@ static MailboxManagerController *singleInstance = nil;
 //
 - (FolderNode *) storeFolderNodeForName: (NSString *) theName
 {
-  int i, count;
+  NSUInteger i, count;
 
   count = [_allFolders count];
   
@@ -2425,7 +2409,7 @@ static MailboxManagerController *singleInstance = nil;
   [_cache setAllValuesForStoreName: aStoreName
 	  folderName: [[theNotification userInfo] objectForKey: @"Name"]
 	  username: aUsername
-	  nbOfMessages: ([[theNotification userInfo] objectForKey: @"Count"] ? [[[theNotification userInfo] objectForKey: @"Count"] intValue] : 0)
+	  nbOfMessages: ([[theNotification userInfo] objectForKey: @"Count"] ? [[[theNotification userInfo] objectForKey: @"Count"] unsignedIntValue] : 0)
 	  nbOfUnreadMessages: 0]; 
   
   [self _folderSubscribeCompleted: theNotification];
@@ -2673,7 +2657,7 @@ static MailboxManagerController *singleInstance = nil;
 {
   NSString *aString;
   id item;
-  int row;
+  NSInteger row;
 
 #warning FIXME get the right item in case the selection has changed
   row = [outlineView selectedRow];
@@ -2695,7 +2679,7 @@ static MailboxManagerController *singleInstance = nil;
 {
   NSString *aString;
   id item;
-  int row;
+  NSInteger row;
 
 #warning FIXME get the right item in case the selection has changed
   row = [outlineView selectedRow];
@@ -2780,8 +2764,8 @@ static MailboxManagerController *singleInstance = nil;
 //
 //
 //
-- (void) _nbOfMessages: (unsigned int *) theNbOfMessages
-    nbOfUnreadMessages: (unsigned int *) theNbOfUnreadMessages
+- (void) _nbOfMessages: (NSUInteger *) theNbOfMessages
+    nbOfUnreadMessages: (NSUInteger *) theNbOfUnreadMessages
                forItem: (id) theItem
 {
   NSString *aString, *aStoreName, *aFolderName, *aUsername;
@@ -2856,7 +2840,7 @@ static MailboxManagerController *singleInstance = nil;
 #warning remove that code or fix it
 #if 0
       FolderNode *item;
-      int i;
+      NSInteger i;
 
       item = [outlineView itemAtRow: [outlineView selectedRow]];
       
@@ -2941,14 +2925,6 @@ static MailboxManagerController *singleInstance = nil;
   // We set the new folder
   [aMailWindowController setFolder: aFolder];
 
-  // We don't try to parse a VirtualFolder
-  if ([aFolder isKindOfClass: [CWLocalFolder class]] && ![aFolder cacheManager])
-    {
-      [aFolder setCacheManager: [[[CWLocalCacheManager alloc] initWithPath: [NSString stringWithFormat: @"%@.%@.cache", [[aFolder path] substringToIndex: ([[aFolder path] length] - [[[aFolder path] lastPathComponent] length])], [[aFolder path] lastPathComponent]]  folder: aFolder] autorelease]];
-      [[aFolder cacheManager] initInRange: NSMakeRange(0, UINT_MAX)];
-      [aFolder parse: NO];
-    }
-
   // We we are reusing our window controller, we must always reload the table view
   if (reusingLastMailWindowOnTop && [GNUMail lastMailWindowOnTop])
     {
@@ -3109,7 +3085,7 @@ static MailboxManagerController *singleInstance = nil;
   // We set the cache manager and we prefetch our messages
   [aFolder setCacheManager: anIMAPCacheManager];
 
-  [[aFolder cacheManager] initInRange: NSMakeRange(0, UINT_MAX)];
+  [[aFolder cacheManager] readAllMessages];
   
   // We set the folder
   [aMailWindowController setFolder: aFolder];
@@ -3307,13 +3283,14 @@ static MailboxManagerController *singleInstance = nil;
   NSMenu *aMenu, *aSubmenu;
   NSMenuItem *aMenuItem;
   NSArray *allKeys;
-  int i, j;
+  NSInteger i;
 
   allKeys = [[Utilities allEnabledAccounts] allKeys];
   aMenu = [[[menu itemArray] lastObject] submenu];
 
   for (i = 0; i < 3; i++)
     {
+      NSUInteger j;
       aMenuItem = (NSMenuItem *)[aMenu itemAtIndex: i];
       
       aSubmenu = [[NSMenu alloc] init];
