@@ -2,8 +2,10 @@
 **  Task.m
 **
 **  Copyright (c) 2002-2007 Ludovic Marcotte
+**  Copyright (C) 2018      Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -19,14 +21,14 @@
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Task.h"
+#import "Task.h"
 
-#include "Constants.h"
+#import "Constants.h"
 
-#include <Foundation/NSArray.h>
-#include <Foundation/NSDebug.h>
-#include <Foundation/NSString.h>
-#include <Foundation/NSValue.h>
+#import <Foundation/NSArray.h>
+#import <Foundation/NSDebug.h>
+#import <Foundation/NSString.h>
+#import <Foundation/NSValue.h>
 
 //
 //
@@ -36,22 +38,23 @@
 - (id) init
 {
   self = [super init];
-
-  [self setMessage: nil];
-  [self setUnmodifiedMessage: nil];
-  [self setKey: nil];
-  [self setSendingKey: nil];
-  [self setDate: [NSDate date]];
-  [self setOwner: nil];
-  [self setFilteredMessagesFolders: [NSMutableArray array]];
-
-  op = sub_op = total_size = current_size = filtered_count = received_count = total_count = 0;
-  is_running = immediate = NO;
-  origin = ORIGIN_USER;
-
-  _controllers = [[NSMutableArray alloc] init];
-  _subtitle = nil;
-
+  if (self)
+    {
+      [self setMessage: nil];
+      [self setUnmodifiedMessage: nil];
+      [self setKey: nil];
+      [self setSendingKey: nil];
+      [self setDate: [NSDate date]];
+      [self setOwner: nil];
+      [self setFilteredMessagesFolders: [NSMutableArray array]];
+      
+      op = sub_op = total_size = current_size = filtered_count = received_count = total_count = 0;
+      is_running = immediate = NO;
+      origin = ORIGIN_USER;
+      
+      _controllers = [[NSMutableArray alloc] init];
+      _subtitle = nil;
+    }
   return self;
 }
 
@@ -97,20 +100,21 @@
 - (id) initWithCoder: (NSCoder *) theCoder
 {
   self = [super init];
-
-  [self setMessage: [theCoder decodeObject]];
-  [self setUnmodifiedMessage: [theCoder decodeObject]];
-  [self setKey: [theCoder decodeObject]];
-  [self setSendingKey: [theCoder decodeObject]];
-  [self setDate: [theCoder decodeObject]];
-  [self setOwner: nil];
-  [self setFilteredMessagesFolders: [NSMutableArray array]];
-
-  op = sub_op = filtered_count = received_count = total_count = 0;
-  is_running = NO;
-  
-  _controllers = [[NSMutableArray alloc] init];
-
+  if (self)
+    {
+      [self setMessage: [theCoder decodeObject]];
+      [self setUnmodifiedMessage: [theCoder decodeObject]];
+      [self setKey: [theCoder decodeObject]];
+      [self setSendingKey: [theCoder decodeObject]];
+      [self setDate: [theCoder decodeObject]];
+      [self setOwner: nil];
+      [self setFilteredMessagesFolders: [NSMutableArray array]];
+      
+      op = sub_op = filtered_count = received_count = total_count = 0;
+      is_running = NO;
+      
+      _controllers = [[NSMutableArray alloc] init];
+    }
   return self;
 }
 
@@ -122,21 +126,22 @@
 {
   Task *aTask;
 
-  aTask = [[Task alloc] init];
-
-  [aTask setMessage: [self message]];
-  [aTask setUnmodifiedMessage: [self unmodifiedMessage]];
-  [aTask setKey: [self key]];
-  [aTask setSendingKey: [self sendingKey]];
-  [aTask setDate: [self date]];
-  [aTask setOwner: [self owner]];
-
-  aTask->op = op;
-  aTask->sub_op = sub_op;
-  aTask->is_running = is_running;
-  aTask->received_count = received_count;
-  aTask->filtered_count = filtered_count;
-
+  aTask = [[Task allocWithZone:zone] init];
+  if (aTask)
+    {
+      [aTask setMessage: [self message]];
+      [aTask setUnmodifiedMessage: [self unmodifiedMessage]];
+      [aTask setKey: [self key]];
+      [aTask setSendingKey: [self sendingKey]];
+      [aTask setDate: [self date]];
+      [aTask setOwner: [self owner]];
+      
+      aTask->op = op;
+      aTask->sub_op = sub_op;
+      aTask->is_running = is_running;
+      aTask->received_count = received_count;
+      aTask->filtered_count = filtered_count;
+    }
   return aTask;
 }
 
