@@ -1032,10 +1032,17 @@ static Class CWSMTP_class;
 	  NSRunAlertPanel(_(@"Error!"), _(@"Unable to connect to the %@ IMAP server."), _(@"OK"), NULL, NULL, [(CWService *)o name]);
 	  [self _taskCompleted: aTask];
 	  
-	  if (aTask->op == CONNECT_ASYNC)
-	    {
-	      [[MailboxManagerController singleInstance] setStore: nil  name: [(CWService *)o name]  username: [o username]];
-	    }
+          if (nil != aTask)
+            {
+	      if (aTask->op == CONNECT_ASYNC)
+	        {
+	          [[MailboxManagerController singleInstance] setStore: nil  name: [(CWService *)o name]  username: [o username]];
+	        }
+            }
+          else
+            {
+              NSLog(@"connectionTimedOut and no valid Task");
+            }
 	}
 
       AUTORELEASE(o);
@@ -1541,7 +1548,7 @@ static Class CWSMTP_class;
       MailboxManagerCache *aCache;
       CWFlags *theFlags;
 
-      unsigned int nbOfMessages, nbOfUnreadMessages;
+      NSUInteger nbOfMessages, nbOfUnreadMessages;
       
       aCache = [(MailboxManagerController *)[MailboxManagerController singleInstance] cache];
       theFlags = [[theNotification userInfo] objectForKey: @"Flags"];
@@ -1795,7 +1802,7 @@ static Class CWSMTP_class;
 {
   NSArray *theMessages;
 
-  unsigned int nbOfTransferredMessages;
+  NSUInteger nbOfTransferredMessages;
 
   theMessages = [[theNotification userInfo] objectForKey: @"Messages"];
   nbOfTransferredMessages = [theMessages count];
@@ -1810,7 +1817,7 @@ static Class CWSMTP_class;
       CWIMAPStore *theStore;
       NSString *aFolderName;
 
-      unsigned int nbOfMessages, nbOfUnreadMessages, nbOfUnreadTransferredMessages, i;
+      NSUInteger nbOfMessages, nbOfUnreadMessages, nbOfUnreadTransferredMessages, i;
 
       aFolderName = [[theNotification userInfo] objectForKey: @"Name"];
       nbOfUnreadTransferredMessages = 0;
@@ -2506,7 +2513,7 @@ static Class CWSMTP_class;
 	      if ([[NSUserDefaults standardUserDefaults] boolForKey: @"SHOW_FILTER_PANEL"])
 		{
 		  NSRunInformationalAlertPanel(_(@"Filtered messages..."),
-					       _(@"%d messages have been transfered to the following folders:\n%@"),
+					       _(@"%d messages have been transferred to the following folders:\n%@"),
 					       _(@"OK"),
 					       NULL,
 					       NULL,
