@@ -2,7 +2,7 @@
 **  Utilities.m
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
-**  Copyright (C) 2015-2017 Riccardo Mottola
+**  Copyright (C) 2015-2018 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -439,6 +439,11 @@ static NSMutableDictionary *passwordCache = nil;
   NSEnumerator *theEnumerator;
   NSString *theAccountName;
 
+  if (theServerName == nil)
+    return nil;
+  if (theUsername == nil)
+    return nil;
+  
   theEnumerator = [[[NSUserDefaults standardUserDefaults] objectForKey: @"ACCOUNTS"] keyEnumerator];
 
   while ((theAccountName = [theEnumerator nextObject]))
@@ -568,7 +573,7 @@ static NSMutableDictionary *passwordCache = nil;
 {
   NSString *aName, *aString;
   FolderNode *root;
-  NSInteger i;
+  NSUInteger i;
  
   root = [[FolderNode alloc] init];
   [root setParent: nil];
@@ -580,10 +585,9 @@ static NSMutableDictionary *passwordCache = nil;
   
   while ((aString = [theFolders nextObject]))
     {
-      //aRange = [aString rangeOfString: theSeparator];
       i = [aString indexOfCharacter: theSeparator];
 
-      if (i >= 0)
+      if (i != NSNotFound)
 	{ 
 	  FolderNode *parent;
 	  NSInteger mark;
@@ -591,7 +595,7 @@ static NSMutableDictionary *passwordCache = nil;
 	  parent = root;
 	  mark = 0;
 	  
-	  while (i > 0)
+	  while (i != NSNotFound && i > 0)
 	    {
 	      if (mark == i)
 		{
@@ -768,7 +772,7 @@ static NSMutableDictionary *passwordCache = nil;
   // We trim the /<Store>/ part.
   i = [aString indexOfCharacter: '/'  fromIndex: 1];
 
-  if (i > 0)
+  if (i != NSNotFound && i > 0)
     {
       return [aString substringFromIndex: i+1];
     }
@@ -1416,7 +1420,6 @@ static NSMutableDictionary *passwordCache = nil;
   CWMessage *aMessage;
   
   BOOL shouldReplyToList, aBOOL;
-  int i;
   
   if (!theMessage || ![theMessage content])
     {
@@ -1449,7 +1452,7 @@ static NSMutableDictionary *passwordCache = nil;
   if ([[theMessage allHeaders] objectForKey: @"List-Post"] &&
       [[[[theMessage allHeaders] objectForKey: @"List-Post"] stringByTrimmingWhiteSpaces] caseInsensitiveCompare: @"NO"] != NSOrderedSame)
     {
-      int choice;
+      NSInteger choice;
       
       choice = NSRunAlertPanel(_(@"List Reply..."),
 			       _(@"To whom would you like to reply?"),
@@ -1479,7 +1482,7 @@ static NSMutableDictionary *passwordCache = nil;
     }
   else if (aBOOL && [theMessage recipientsCount] > 1)
     {
-      int choice;
+      NSInteger choice;
       
       choice = NSRunAlertPanel(_(@"Reply..."),
 			       _(@"Would you like to reply to all recipients?"),
@@ -1528,7 +1531,8 @@ static NSMutableDictionary *passwordCache = nil;
       // if we reply only to a mailing list since the recipients will get replaced below.
       if (!shouldReplyToList && (theMode&PantomimeReplyAllMode) && theAccountAddress)
 	{
-	  for (i = ([aMessage recipientsCount]-1); i >= 0; i--)
+          NSUInteger i;
+	  for (i = 0; i < [aMessage recipientsCount]; i++)
 	    {
 	      if ([[(CWInternetAddress*)[[aMessage recipients] objectAtIndex: i] address] 
 		    caseInsensitiveCompare: theAccountAddress] == NSOrderedSame)
@@ -1629,7 +1633,7 @@ static NSMutableDictionary *passwordCache = nil;
     {
       CWFlags *theFlags;
       id aDelegate;
-      int i, count;
+      NSUInteger i, count;
 
       if ([theMessage isKindOfClass: [CWIMAPMessage class]] && ![(CWIMAPFolder *)[theMessage folder] selected])
       	{
@@ -1843,7 +1847,8 @@ static NSMutableDictionary *passwordCache = nil;
 	}
       
       theAttributedString = [[NSAttributedString alloc] initWithString: aString attributes: theAttributes];
-      [[theTextView textStorage] setAttributedString: theAttributedString];
+      if (theAttributedString)
+        [[theTextView textStorage] setAttributedString: theAttributedString];
       RELEASE(theAttributedString);
      
       // We scroll to the beginning of the message and we remove any previous text selection
@@ -2027,7 +2032,7 @@ static NSMutableDictionary *passwordCache = nil;
 	}
       else
 	{
-	  int i;
+	  NSUInteger i;
 	  
 	  for (i = 0; i < [foldersToOpen count]; i++)
 	    {
@@ -2196,4 +2201,4 @@ NSString *GNUMailCopyrightInfo()
 #else
   return [[[NSBundle mainBundle] infoDictionary] objectForKey: @"Copyright"];
 #endif
-}
\ No newline at end of file
+}
